test/unittest_rset.py
changeset 1977 606923dff11b
parent 1640 65b60f177eb1
child 2286 5dd33f9b7b84
--- a/test/unittest_rset.py	Thu May 28 08:06:12 2009 +0200
+++ b/test/unittest_rset.py	Thu May 28 09:20:07 2009 +0200
@@ -1,5 +1,11 @@
 # coding: utf-8
-"""unit tests for module cubicweb.common.utils"""
+"""unit tests for module cubicweb.common.utils
+
+:organization: Logilab
+:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+"""
 from __future__ import with_statement
 
 from logilab.common.testlib import TestCase, unittest_main